@@ -123,6 +123,9 @@ sub get_pixel {
 
 sub set_pixel {
 	my ( $self, $y, $x, $new_value ) = @_;
+
+	$new_value = SDLx::Validate::num_rgba($new_value);
+
 	SDLx::Surface::set_pixel_xs( $self, $x, $y, $new_value );
 }
 
@@ -143,6 +146,9 @@ sub _array {
 
 sub surface { $_[0] }
 
+sub width { $_[0]->w }
+sub height { $_[0]->h }
+
 #WRAPPING
 
 sub clip_rect {
@@ -188,33 +194,6 @@ sub load {
 
 #EXTENSTIONS
 
-sub blit {
-	my ( $src, $dest, $src_rect, $dest_rect ) = @_;
-
-	$src = SDLx::Validate::surface($src);
-	$dest = SDLx::Validate::surface($dest);
-
-	if(defined $src_rect) {
-		$src_rect = SDLx::Validate::rect($src_rect);
-	}
-	else {
-		$src_rect = SDL::Rect->new( 0, 0, $src->w, $src->h );
-	}
-	if(defined $dest_rect) {
-		$dest_rect = SDLx::Validate::rect($dest_rect);
-	}
-	else {
-		$dest_rect = SDL::Rect->new( 0, 0, $dest->w, $dest->h );
-	}
-
-	SDL::Video::blit_surface(
-		$src, $src_rect,
-		$dest, $dest_rect
-	);
-
-	return $src;
-}
-
 sub blit_by {
 	my ( $dest, $src, $src_rect, $dest_rect ) = @_;
 	SDLx::Surface::blit( $src, $dest, $src_rect, $dest_rect );
@@ -261,20 +240,6 @@ sub update {
 	return $surface;
 }
 
-sub draw_rect {
-	my ( $self, $rect, $color ) = @_;
-	$color = SDLx::Validate::map_rgba( $color, $self->format );
-	if ( defined $rect ) {
-		$rect = SDLx::Validate::rect($rect);
-	} else {
-		$rect = SDL::Rect->new( 0, 0, $self->w, $self->h );
-	}
-
-	SDL::Video::fill_rect( $self, $rect, $color )
-		and Carp::confess "Error drawing rect: " . SDL::get_error();
-	return $self;
-}
-
 sub draw_line {
 	my ( $self, $start, $end, $color, $antialias ) = @_;
 
@@ -313,12 +278,19 @@ sub draw_circle {
 	Carp::cluck "Center needs to be an array of format [x,y]" unless ( ref $center eq 'ARRAY' && scalar @$center == 2 );
 	$color = SDLx::Validate::num_rgba($color);
 
-	SDL::GFX::Primitives::circle_color( $self, @{$center}, $radius, $color );
+	unless( $antialias )
+	{
+		SDL::GFX::Primitives::circle_color( $self, @{$center}, $radius, $color );
+	}
+	else
+	{
+		SDL::GFX::Primitives::aacircle_color( $self, @{$center}, $radius, $color );
+	}
 	return $self;
 }
 
 sub draw_circle_filled {
-	my ( $self, $center, $radius, $color, $antialias ) = @_;
+	my ( $self, $center, $radius, $color) = @_;
 
 	unless ( SDL::Config->has('SDL_gfx_primitives') ) {
 		Carp::cluck("SDL_gfx_primitives support has not been compiled");
@@ -329,6 +301,7 @@ sub draw_circle_filled {
 	$color = SDLx::Validate::num_rgba($color);
 
 	SDL::GFX::Primitives::filled_circle_color( $self, @{$center}, $radius, $color );
+
 	return $self;
 }
 
